@@ -6,8 +6,7 @@
 # Patched by Brad Chapman.
 # Chris Wroe added modifications for work in myGrid
 
-"""NCBIWWW.py
-
+"""
 This module provides code to work with the WWW version of BLAST
 provided by the NCBI.
 http://www.ncbi.nlm.nih.gov/BLAST/
@@ -17,22 +16,21 @@ BlastParser   Parses output from WWW blast.
 _Scanner      Scans output from NCBI's BLAST WWW server.
 
 Functions:
-blast         Do a BLAST search against the WWW page.
-blasturl      Do a BLAST search against the stable blasturl.
+blast         Do a BLAST search against the WWW page. (Deprecated)
+blasturl      Do a BLAST search against the stable blasturl. (Deprecated)
+qblast        Do a BLAST search using the QBLAST API.
 
 """
 import string
-import time
 import re
 import sgmllib
-import urlparse
-import socket
-import cStringIO
 
-from Bio import File
-from Bio.WWW import NCBI
+try:
+    import cStringIO as StringIO
+except ImportError:
+    import StringIO
+
 from Bio.ParserSupport import *
-import NCBIStandalone
 
 class BlastParser(AbstractParser):
     """Parses WWW BLAST data into a Record.Blast object.
@@ -40,6 +38,7 @@ class BlastParser(AbstractParser):
     """
     def __init__(self):
         """__init__(self)"""
+        import NCBIStandalone
         self._scanner = _Scanner()
         self._consumer = SGMLStrippingConsumer(NCBIStandalone._BlastConsumer())
 
@@ -66,6 +65,8 @@ class _Scanner:
         object that will receive events as the report is scanned.
 
         """
+        from Bio import File
+
         # This stuff appears in 2.0.12.
         # <p><!--
         # QBlastInfoBegin
@@ -156,8 +157,10 @@ class _Scanner:
 
         # Read the RID line, for version 2.0.12 (2.0.11?) and above.
         attempt_read_and_call(uhandle, consumer.noevent, start='RID')
-        # Brad Chapman noticed a '<p>' line in BLASTN 2.1.1
-        attempt_read_and_call(uhandle, consumer.noevent, start='<p>')
+        # Brad Chapman noticed a '<p>' line in BLASTN 2.1.1; this line
+        # seems to have disappeared again.
+        # attempt_read_and_call(uhandle, consumer.noevent, start='<p>')
+        attempt_read_and_call(uhandle, consumer.noevent)
 
         # Apparently, there's some discrepancy between whether the
         # Query or database comes first.  Usually the Query does, but
@@ -236,7 +239,6 @@ class _Scanner:
         if attempt_read_and_call(uhandle, consumer.noevent, start="<PRE>"):
             read_and_call_while(uhandle, consumer.noevent, blank=1)
         self._scan_blastform(uhandle, consumer)
-            
         
     def _scan_rounds(self, uhandle, consumer):
         self._scan_descriptions(uhandle, consumer)
@@ -303,6 +305,9 @@ class _Scanner:
         #   </form>
         #   <script src="blastResult.js"></script><table border="0"><tr><td><FO
         #   <PRE>
+        # 6) Qblast 2.2.10, database (no 'Database' line)
+        #  <PRE>
+        #  Lambda     K      H
 
         # Get the first two lines and examine them.
         line1 = safe_readline(uhandle)
@@ -311,16 +316,20 @@ class _Scanner:
         uhandle.saveline(line1)
 
         is_pairwise = is_masterslave = 0
-        if string.find(line1, 'Alignments') >= 0:
+#        Was line1, changed to line2. 16-feb-2005. Iddo
+#        if string.find(line1, 'Alignments') >= 0:
+        if string.find(line2, 'Alignments') >= 0:
             is_pairwise = 1
         elif line2[:10] == '  Database':
             pass
+        elif line2[:19] == 'Lambda     K      H':
+            pass
         elif line2[:9] == 'blast_tmp':
             is_masterslave = 1
         elif line1[:5] == '<PRE>':
             is_pairwise = 1
         else:
-            raise SyntaxError, "Cannot resolve location at line:\n%s" % line1
+            raise SyntaxError, "Cannot resolve location at lines:\n%s\n%s" % (line1, line2)
 
         if is_pairwise:
             self._scan_pairwise_alignments(uhandle, consumer)
@@ -337,7 +346,9 @@ class _Scanner:
             line2 = safe_readline(uhandle)
             uhandle.saveline(line2)
             uhandle.saveline(line1)
-            if line1.find('Database') >= 0 or line2.find("Database") >= 0:
+            # Lambda is for Q-blast results, which do not have a Database line
+            if line1.find('Database') >= 0 or line2.find("Database") >= 0 \
+                or line2.find('Lambda     K      H') >= 0:
                 break
 
             # Occasionally, there's a bug where the alignment_header and
@@ -502,21 +513,28 @@ class _Scanner:
         #    0.270   0.0470    0.230 
         # 
 
+        # qblast (BLASTN 2.2.10) does not give the Database: bits before the Lambda
+        # information, so that needs to be skipped
+
         consumer.start_database_report()
 
         # TBALSTN 2.2.6
         # <PRE>  Database: /tmp/affyA.fasta
         line = uhandle.peekline()
+        # only look for database information if we aren't already at the
+        # Lambda bits
         if line.find("Database") < 0:
             read_and_call(uhandle, consumer.noevent, start='<PRE>')
-        read_and_call(uhandle, consumer.database, contains='  Database')
-        read_and_call_until(uhandle, consumer.database, contains="Posted")
-        read_and_call(uhandle, consumer.posted_date, start='    Posted')
-        read_and_call(uhandle, consumer.num_letters_in_database,
-                      start='  Number of letters')
-        read_and_call(uhandle, consumer.num_sequences_in_database,
-                      start='  Number of sequences')
-        read_and_call(uhandle, consumer.noevent, start='  ')
+        line2 = uhandle.peekline()
+        if line2.find("Lambda     K      H") < 0:
+            read_and_call(uhandle, consumer.database, contains='  Database')
+            read_and_call_until(uhandle, consumer.database, contains="Posted")
+            read_and_call(uhandle, consumer.posted_date, start='    Posted')
+            read_and_call(uhandle, consumer.num_letters_in_database,
+                          start='  Number of letters')
+            read_and_call(uhandle, consumer.num_sequences_in_database,
+                          start='  Number of sequences')
+            read_and_call(uhandle, consumer.noevent, start='  ')
 
         read_and_call(uhandle, consumer.noevent, start='Lambda')
         read_and_call(uhandle, consumer.ka_params)
@@ -560,13 +578,23 @@ class _Scanner:
 
         consumer.start_parameters()
 
-        read_and_call(uhandle, consumer.matrix, start='Matrix')
+        # qblast doesn't have Matrix line
+        attempt_read_and_call(uhandle, consumer.matrix, start='Matrix')
         # not TBLASTX
         attempt_read_and_call(uhandle, consumer.gap_penalties, start='Gap')
-        read_and_call(uhandle, consumer.num_hits,
-                      start='Number of Hits')
-        read_and_call(uhandle, consumer.num_sequences,
-                      start='Number of Sequences')
+        
+        # in qblast the Number of Hits and Number of Sequences lines are
+        # reversed
+        if attempt_read_and_call(uhandle, consumer.num_hits,
+                start='Number of Hits'):
+            read_and_call(uhandle, consumer.num_sequences,
+                          start='Number of Sequences')
+        else:
+            read_and_call(uhandle, consumer.num_sequences,
+                          start='Number of Sequences')
+            read_and_call(uhandle, consumer.num_hits,
+                          start='Number of Hits')
+
         read_and_call(uhandle, consumer.num_extends,
                       start='Number of extensions')
         read_and_call(uhandle, consumer.num_good_extends,
@@ -578,32 +606,56 @@ class _Scanner:
         # not BLASTN, TBLASTX
         if attempt_read_and_call(uhandle, consumer.hsps_no_gap,
                                  start="Number of HSP's better"):
-            read_and_call(uhandle, consumer.hsps_prelim_gapped,
-                          start="Number of HSP's successfully")
-            read_and_call(uhandle, consumer.hsps_prelim_gap_attempted,
-                          start="Number of HSP's that")
-            read_and_call(uhandle, consumer.hsps_gapped,
-                          start="Number of HSP's gapped")
+            # for qblast order of HSP info is changed
+            if attempt_read_and_call(uhandle, consumer.hsps_prelim_gapped,
+                    start="Number of HSP's successfully"):
+                read_and_call(uhandle, consumer.hsps_prelim_gap_attempted,
+                              start="Number of HSP's that")
+                read_and_call(uhandle, consumer.hsps_gapped,
+                              start="Number of HSP's gapped")
+            else:
+                read_and_call(uhandle, consumer.no_event,
+                              start="Number of HSP's gapped")
+                read_and_call(uhandle, consumer.no_event,
+                              start="Number of HSP's successfully")
+                read_and_call(uhandle, consumer.no_event,
+                              start="Number of extra gapped")
+        
+        # QBlast has different capitalization on the Length info:
+        if attempt_read_and_call(uhandle, consumer.query_length,
+                start='Length of query'):
+            read_and_call(uhandle, consumer.database_length,
+                start='Length of database')
+            read_and_call(uhandle, consumer.no_event,
+                          start='Length adjustment')
+            attempt_read_and_call(uhandle, consumer.effective_query_length,
+                                  start='Effective length of query')
+            read_and_call(uhandle, consumer.effective_database_length,
+                          start='Effective length of database')
+            attempt_read_and_call(uhandle, consumer.effective_search_space,
+                                  start='Effective search space:')
+            attempt_read_and_call(uhandle, consumer.effective_search_space_used,
+                                  start='Effective search space used')
 
-        attempt_read_and_call(uhandle, consumer.query_length,
-                              start='length of query')
-        read_and_call(uhandle, consumer.database_length,
-                      start='length of database')
-
-        read_and_call(uhandle, consumer.effective_hsp_length,
-                      start='effective HSP')
-        attempt_read_and_call(uhandle, consumer.effective_query_length,
-                              start='effective length of query')
-        read_and_call(uhandle, consumer.effective_database_length,
-                      start='effective length of database')
-        attempt_read_and_call(uhandle, consumer.effective_search_space,
-                              start='effective search space:')
-        attempt_read_and_call(uhandle, consumer.effective_search_space_used,
-                              start='effective search space used')
+        else:
+            attempt_read_and_call(uhandle, consumer.query_length,
+                                  start='length of query')
+            read_and_call(uhandle, consumer.database_length,
+                start='length of database')
+            read_and_call(uhandle, consumer.effective_hsp_length,
+                          start='effective HSP')
+            attempt_read_and_call(uhandle, consumer.effective_query_length,
+                                  start='effective length of query')
+            read_and_call(uhandle, consumer.effective_database_length,
+                          start='effective length of database')
+            attempt_read_and_call(uhandle, consumer.effective_search_space,
+                                  start='effective search space:')
+            attempt_read_and_call(uhandle, consumer.effective_search_space_used,
+                                  start='effective search space used')
 
         # BLASTX, TBLASTN, TBLASTX
         attempt_read_and_call(uhandle, consumer.frameshift, start='frameshift')
-        read_and_call(uhandle, consumer.threshold, start='T')
+        attempt_read_and_call(uhandle, consumer.threshold, start='T')
         read_and_call(uhandle, consumer.window_size, start='A')
         read_and_call(uhandle, consumer.dropoff_1st_pass, start='X1')
         read_and_call(uhandle, consumer.gap_x_dropoff, start='X2')
@@ -636,7 +688,7 @@ def blast(program, database, query,
           show_overview='on',
           ncbi_gi='on',
           format_object='alignment',
-          format_type='html',
+          format_type='HTML',
           descriptions='100',
           alignments='50',
           alignment_view='Pairwise',
@@ -681,6 +733,13 @@ def blast(program, database, query,
     genetic code
     
     """
+    import time
+    import urlparse
+    from Bio.WWW import NCBI
+    
+    import warnings
+    warnings.warn("blast is deprecated.  Please use qblast instead.")
+    
     # NCBI Blast is hard to work with.  The user enters a query, and then
     # it returns a "reference" page which contains a button that the user
     # clicks to retrieve the results.  This will retrieve the "results"
@@ -759,7 +818,7 @@ def blast(program, database, query,
     if output_fn is not None:
         results = handle.read()
         output_fn(results)
-        handle = File.StringHandle(results)
+        handle = StringIO.StringIO(results)
     ref_cgi, ref_params = _parse_blast_ref_page(handle)
     ref_cgi = urlparse.urljoin(cgi, ref_cgi)  # convert to absolute URL
 
@@ -777,7 +836,7 @@ def blast(program, database, query,
         if output_fn is not None:
             results = handle.read()
             output_fn(results)
-            handle = File.StringHandle(results)
+            handle = StringIO.StringIO(results)
         ready, results_cgi, results_params = _parse_blast_results_page(handle)
         results_params['FORMAT_TYPE']=format_type
         results_params['NCBI_GI']='yes'
@@ -913,6 +972,8 @@ def blasturl(program, datalib, sequence,
     http://www.ncbi.nlm.nih.gov/BLAST/blast_overview.html
     
     """
+    import warnings
+    warnings.warn("blasturl is deprecated.  Please use qblast instead.")
     lines = []
     lines.append('PROGRAM %s' % program)
     lines.append('DATALIB %s' % datalib)
@@ -928,7 +989,7 @@ def blasturl(program, datalib, sequence,
                   ('FILTER', filter),
                   ('HTML', html),
                   ('GCODE', gcode),
-                  ('PATH', path)
+                  ('PATH', path),
                   ]
     for name, value in parameters:
         if value is not None:
@@ -942,7 +1003,7 @@ def blasturl(program, datalib, sequence,
 
     message = string.join(lines, '\n')
 
-    outhandle = cStringIO.StringIO()
+    outhandle = StringIO.StringIO()
     _send_to_blasturl(message, outhandle)
     outhandle.seek(0)   # Reset the handle to the beginning.
     return outhandle
@@ -955,6 +1016,7 @@ def _send_to_blasturl(query, outhandle):
     The results are written to outhandle.
     
     """
+    import socket
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     sock.connect(('www.ncbi.nlm.nih.gov', 80))
     
@@ -972,3 +1034,145 @@ def _send_to_blasturl(query, outhandle):
             break
         outhandle.write(data)
     sock.close()
+
+def qblast(program, database, sequence,
+           ncbi_gi=None, descriptions=None, alignments=None,
+           expect=None, matrix=None,
+           filter=None, format_type="XML", hitlist_size=None,
+           entrez_query='(none)',
+           ):
+    """Do a BLAST search using the QBLAST server at NCBI.
+    program        BLASTP, BLASTN, BLASTX, TBLASTN, or TBLASTX.
+    database       Which database to search against.
+    sequence       The sequence to search.
+    ncbi_gi        TRUE/FALSE whether to give 'gi' identifier.  Def FALSE.
+    descriptions   Number of descriptions to show.  Def 500.
+    alignments     Number of alignments to show.  Def 500.
+    expect         An expect value cutoff.  Def 10.0.
+    matrix         Specify an alt. matrix (PAM30, PAM70, BLOSUM80, BLOSUM45).
+    filter         "none" turns off filtering.  Default uses 'seg' or 'dust'.
+    format_type    "HTML", "Text", "ASN.1", or "XML".  Def. "XML".
+    entrez_query   Entrez query to limit Blast search
+
+    This function does no checking of the validity of the parameters
+    and passes the values to the server as is.  More help is available at:
+    http://www.ncbi.nlm.nih.gov/BLAST/blast_overview.html
+
+    """
+    import urllib
+    from Bio.WWW import RequestLimiter
+
+    # Is this warning useful?  If the program is blastn or blastp, the
+    # warning is not necessary because the program is supported.  If
+    # it is not, the script will raise an exception anyway.
+    # - Jeff
+    import warnings
+    warnings.warn("qblast works only with blastn and blastp for now.")
+    assert program == 'blastn' or program == 'blastp'
+
+    # hitlist_size parameter contributed by Sjoerd de Vries.
+    parameters = [
+        ('QUERY', sequence),
+        ('PROGRAM', program),
+        ('ENTREZ_QUERY', entrez_query),
+        ('DATABASE', database),
+        ('EXPECT', expect),
+        ('HITLIST_SIZE', hitlist_size),
+        ('MATRIX_NAME', matrix),
+        ('FILTER', filter),
+        ('CMD', 'Put'),
+        ]
+    query = [x for x in parameters if x[1] is not None]
+    message = urllib.urlencode(query)
+
+    # Send off the initial query to qblast.
+    handle = _send_to_qblast(message)
+
+    # Format the query now.
+    rid, rtoe = _parse_qblast_ref_page(handle)
+    parameters = [
+        ("RID", rid),
+        ('DESCRIPTIONS', descriptions),
+        ('ALIGNMENTS', alignments),
+        ('NCBI_GI', ncbi_gi),
+        ('FORMAT_TYPE', format_type),
+        ("CMD", "Get"),
+        ]
+    query = [x for x in parameters if x[1] is not None]
+    message = urllib.urlencode(query)
+
+    # Poll NCBI until the results are ready.
+    limiter = RequestLimiter(3)
+    while 1:
+        limiter.wait()
+        handle = _send_to_qblast(message)
+        results = handle.read()
+
+        # XML results don't have the Status tag.
+        if results.find("Status=") < 0:
+            break
+        i = results.index("Status=")
+        j = results.index("\n", i)
+        status = results[i+len("Status="):j].strip()
+        if status.upper() == "READY":
+            break
+
+    # results come with this kind of header:
+
+    # HTTP/1.1 200 OK
+    # Date: Wed, 05 Oct 2005 02:13:33 GMT
+    # Server: Nde
+    # Content-Type: text/plain
+    # Connection: close
+    # 
+
+    # As the parser will choke on this header, we need to remove it
+    i = results.index("Connection: close")
+    i = results.index("\n",i)
+    i = results.index("\n",i+1)
+    results = results[i+1:]
+
+    return StringIO.StringIO(results)
+
+def _send_to_qblast(query):
+    """Send a BLAST request to the QBLAST server at NCBI.
+    http://www.ncbi.nlm.nih.gov/BLAST/Doc/urlapi.html
+
+    Return a handle to the results.
+    
+    """
+    import socket
+    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    sock.connect(('www.ncbi.nlm.nih.gov', 80))
+    
+    sock.send('POST /blast/Blast.cgi HTTP/1.0\n')
+    sock.send('User-Agent: BiopythonClient\n')
+    sock.send('Connection: Keep-Alive\n')
+    sock.send('Content-type: application/x-www-form-urlencoded\n')
+    sock.send('Content-Length: %d\n' % len(query))
+    sock.send('\n')
+    sock.send(query)
+
+    handle = StringIO.StringIO()
+    while 1:
+        data = sock.recv(1024)
+        if not data:
+            break
+        handle.write(data)
+    sock.close()
+    
+    handle.seek(0)
+    return handle
+
+def _parse_qblast_ref_page(handle):
+    """Return tuple of RID, RTOE."""
+    s = handle.read()
+    i = s.find("RID =")
+    j = s.find("\n", i)
+    rid = s[i+len("RID ="):j].strip()
+
+    i = s.find("RTOE =")
+    j = s.find("\n", i)
+    rtoe = s[i+len("RTOE ="):j].strip()
+    return rid, int(rtoe)
+    
