@@ -1,17 +1,16 @@
 # Clustalw modules
 
-"""Clustalw.py
-
+"""
 A set of classes to interact with the multiple alignment command
-line program Clustalw (which is the command line version of the current
-graphical Clustalx aligment program).
+line program clustalw. 
 
-This requires Clustalw1.8.1 available from:
+Clustalw is the command line version of the graphical Clustalx 
+aligment program.
+
+This requires clustalw available from:
 
 ftp://ftp-igbmc.u-strasbg.fr/pub/ClustalW/.
 
-Older versions may work, but haven't been tested yet.
-
 functions:
 o parse_file
 o do_alignment
@@ -21,10 +20,6 @@ o ClustalAlignment
 o _AlignCreator
 o MultipleAlignCL"""
 
-__all__ = [
-    'clustal_format',
-    ]
-
 # standard library
 import os
 import string
@@ -41,7 +36,7 @@ from Bio.Align.Generic import Alignment
 from xml.sax import saxutils
 from xml.sax import handler
 
-def parse_file(file_name, alphabet = IUPAC.unambiguous_dna):
+def parse_file(file_name, alphabet = IUPAC.unambiguous_dna, debug_level = 0):
     """Parse the given file into a clustal aligment object.
     
     Arguments:
@@ -52,7 +47,7 @@ def parse_file(file_name, alphabet = IUPAC.unambiguous_dna):
     """ 
     align_handler = _AlignCreator(Alphabet.Gapped(alphabet))
 
-    parser = clustal_format.format.make_parser()
+    parser = clustal_format.format.make_parser(debug_level)
     parser.setContentHandler(align_handler)
     parser.setErrorHandler(handler.ErrorHandler())
 
@@ -77,8 +72,11 @@ def do_alignment(command_line, alphabet=None):
     If the alignment type was not a clustal object, None is returned.
     """
     run_clust = os.popen(str(command_line))
-    value = run_clust.close()
+    status = run_clust.close()
 
+    # The exit status is the second byte of the termination status
+    value = 0
+    if status: value = status / 256
     # check the return value for errors, as on 1.81 the return value
     # from Clustalw is actually helpful for figuring out errors
     # 1 => bad command line option
@@ -388,7 +386,8 @@ class MultipleAlignCL:
         if self.type:
             cline = cline + " -TYPE=%s" % self.type
         if self.is_quick == 1:
-            cline = cline + " -INTERACTIVE"
+            #cline = cline + " -INTERACTIVE"
+            cline = cline + " -QUICKTREE"
         if self.allow_negative == 1:
             cline = cline + " -NEGATIVE"
 
