@@ -3,8 +3,7 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-"""SProt.py
-
+"""
 This module provides code to work with the sprotXX.dat file from
 SwissProt.
 http://www.expasy.ch/sprot/sprot-top.html
@@ -20,7 +19,7 @@ Iterator           Iterates over entries in a SwissProt file.
 Dictionary         Accesses a SwissProt file using a dictionary interface.
 ExPASyDictionary   Accesses SwissProt records from ExPASy.
 RecordParser       Parses a SwissProt record into a Record object.
-SequenceParser     Parses a SwissProt record into a Seq object.
+SequenceParser     Parses a SwissProt record into a SeqRecord object.
 
 _Scanner           Scans SwissProt-formatted data.
 _RecordConsumer    Consumes SwissProt data to a Record object.
@@ -292,11 +291,10 @@ class RecordParser(AbstractParser):
         return self._consumer.data
 
 class SequenceParser(AbstractParser):
-    """Parses SwissProt data into a Seq object.
-
+    """Parses SwissProt data into a standard SeqRecord object.
     """
     def __init__(self, alphabet = Alphabet.generic_protein):
-        """Initialize a RecordParser.
+        """Initialize a SequenceParser.
 
         Arguments:
         o alphabet - The alphabet to use for the generated Seq objects. If
@@ -379,10 +377,12 @@ class _Scanner:
     def _scan_dt(self, uhandle, consumer):
         self._scan_line('DT', uhandle, consumer.date, exactly_one=1)
         self._scan_line('DT', uhandle, consumer.date, exactly_one=1)
-        self._scan_line('DT', uhandle, consumer.date, exactly_one=1)
+        # IPI doesn't necessarily contain the third line about annotations
+        self._scan_line('DT', uhandle, consumer.date, up_to_one=1)
 
     def _scan_de(self, uhandle, consumer):
-        self._scan_line('DE', uhandle, consumer.description, one_or_more=1)
+        # IPI can be missing a DE line
+        self._scan_line('DE', uhandle, consumer.description, any_number=1)
     
     def _scan_gn(self, uhandle, consumer):
         self._scan_line('GN', uhandle, consumer.gene_name, any_number=1)
@@ -430,11 +430,21 @@ class _Scanner:
     
     def _scan_rx(self, uhandle, consumer):
         self._scan_line('RX', uhandle, consumer.reference_cross_reference,
-                        up_to_one=1)
+                        any_number=1)
     
     def _scan_ra(self, uhandle, consumer):
+        # In UniProt release 1.12 of 6/21/04, there is a new RG
+        # (Reference Group) line, which references a group instead of
+        # an author.  Each block must have at least 1 RA or RG line.
         self._scan_line('RA', uhandle, consumer.reference_author,
-                        one_or_more=1)
+                        any_number=1)
+        self._scan_line('RG', uhandle, consumer.reference_author,
+                        any_number=1)
+        # PRKN_HUMAN has RG lines, then RA lines.  The best solution
+        # is to write code that accepts either of the line types.
+        # This is the quick solution...
+        self._scan_line('RA', uhandle, consumer.reference_author,
+                        any_number=1)
     
     def _scan_rt(self, uhandle, consumer):
         self._scan_line('RT', uhandle, consumer.reference_title,
@@ -528,29 +538,38 @@ class _RecordConsumer(AbstractConsumer):
     
     def date(self, line):
         uprline = string.upper(line)
+        
+        # find where the version information will be located
+        # This is needed for when you have cases like IPI where
+        # the release verison is in a different spot:
+        # DT   08-JAN-2002 (IPI Human rel. 2.3, Created)
+        uprcols = uprline.split()
+        rel_index = -1
+        for index in range(len(uprcols)):
+            if uprcols[index].find("REL.") >= 0:
+                rel_index = index
+        assert rel_index >= 0, \
+                "Could not find Rel. in DT line: %s" % (line)
+        version_index = rel_index + 1
+        # get the version information
         cols = line.split()
+        str_version = self._chomp(cols[version_index])
+        # no version number
+        if str_version == '':
+            version = 0
+        # dot versioned
+        elif str_version.find(".") >= 0:
+            version = str_version
+        # integer versioned
+        else:
+            version = int(str_version)
+
         if uprline.find("CREATED") >= 0:
-            # ws:2001-12-05 prevent e.g. (IPIrel. , created)
-            # !no number given! from crashing
-            if self._chomp(cols[3]) == '':                            #<=
-                self.data.created = cols[1], 0                        #<=
-	    else:	                                              #<=
-                self.data.created = cols[1], int(self._chomp(cols[3]))
+            self.data.created = cols[1], version
         elif uprline.find('LAST SEQUENCE UPDATE') >= 0:
-            # ws:2001-12-05 prevent e.g. (IPIrel. , created)
-            # !no number given! from crashing
-            if self._chomp(cols[3]) == '':                            #<=
-                self.data.sequence_update = cols[1], 0                #<=
-	    else:                                                     #<=
-                self.data.sequence_update = cols[1], int(self._chomp(cols[3]))
+            self.data.sequence_update = cols[1], version
         elif uprline.find( 'LAST ANNOTATION UPDATE') >= 0:
-            # ws:2001-12-05 prevent e.g. (IPIrel. , created)
-            # !no number given! from crashing
-            if self._chomp(cols[3]) == '':                               #<=
-                self.data.annotation_update = cols[1], 0                 #<=
-	    else:                                                        #<=
-                self.data.annotation_update = cols[1], \
-                                              int(self._chomp(cols[3]))  #<=
+            self.data.annotation_update = cols[1], version
         else:
             raise SyntaxError, "I don't understand the date line %s" % line
     
@@ -827,12 +846,11 @@ class _RecordConsumer(AbstractConsumer):
             setattr(ref, m, attr.rstrip())
 
 class _SequenceConsumer(AbstractConsumer):
-    """Consumer that converts a SwissProt record to a Seq object.
+    """Consumer that converts a SwissProt record to a SeqRecord object.
 
     Members:
     data      Record with SwissProt data.
     alphabet  The alphabet the generated Seq objects will have.
-
     """
     def __init__(self, alphabet = Alphabet.generic_protein):
         """Initialize a Sequence Consumer
